function [T, numdet] = fabangle(fans, xmin, xmax, ymin, ymax, nx, ny)

% function [T, numdet] = fabangle(fans, xmin, xmax, ymin, ymax, nx, ny)
%
% Calculation of the T matrix for a rectangular grid using precalculated
% matrices of solid angles for all detectors and a grid of 0.5x0.5x0.5cm^3
% matrices are stored in fabangle_#.mat files located in the subdirectory
% \fabsolidangle\.
%
% History:        
%
%  Matthias Anton, CRPP EPFL, 30 of May, 1995 (first release)
%  Matthias Anton, CRPP EPFL, 23 of November, 1995
%  Iwan Jerjen, CRPP EPFL, 12 of July, 1998
%  Jan Mlynar, CRPP EPFL, 20 of August, 1998 (adaption for bolometry)
%  
% Final release version 1.4 (2002/02/07)

debut=cputime;
detn=[];

for j=1:length(fans)

  if fans(j)

    detn=[detn,(j-1)*8+1:j*8];
    
  end

end

ndet=length(detn);

dx=(xmax-xmin)/nx;
dy=(ymax-ymin)/ny;
xgrid=xmin+dx/2:dx:xmax-dx/2;
ygrid=ymin+dy/2:dy:ymax-dy/2;

xpix=ones(size(ygrid'))*xgrid;
ypix=ygrid'*ones(size(xgrid));
xpix=xpix(:);
ypix=ypix(:);

T=zeros(ndet,nx*ny);

for k=1:ndet	

  eval(['load fabsolidangle/fabsolidangle_'...
			,int2str(detn(k))])

  for l = 1 : nx*ny
		
    drin=find(rhoici>=xpix(l)-dx/2 & rhoici<=xpix(l)+dx/2 ....
			  & zetici>=ypix(l)-dy/2 & zetici<=ypix(l)+dy/2);
	T(k,l)=sum(omeici(drin))*dV;
    
  end

end
 
load fabchord 
  
[Th,numh]=fabstandard(100.*xchord,100.*ychord,xmin,xmax,ymin,ymax,nx,ny);

for i=1:64
    
  linst=find(numh==i);

  if ~isempty(linst)

    leng=sum(Th(linst,:));
    
  else
  
    leng=0; 
    
  end
  
  viv=sum(T(i,:));

  if viv~=0

    cor=leng/viv;
    
  else
    
    cor=0;
    
  end
  
  T(i,:)=T(i,:)*cor;  
  
end

numdet=find(sum(T'));
T=T(numdet,:);
numdet=detn(numdet);

time_end = cputime - debut;
disp(['CPU runtime: ' num2str(time_end),' s.']);
disp('  ');