function [con_xt, con_yt, c_xt, c_yt, c_times] = ...
    fablcfs(shot, times)

% function [con_xt, con_yt, c_xt, c_yt, c_times] = ...
%    fablcfs(shot, times)
%
% This routine returns matrices of the contours of the
% LCFS from LIUQE for #shot as well as the magnetic axis.
% 'c_times' contains the LIUQE times which were nearest
% to the values specified in the vector "times".
%
% size of con_xt is [npts_contour x length(c_times)]
% size of c_yt is [1 x length(c_times)].
%
% This routine has been taken form the 'btomo.m' package
%
% History:        
%
%  Matthias Anton, CRPP EPFL, 1995 (first release)
%  Iwan Jerjen, CRPP EPFL, 23 of August, 1999 (minor modifications)
%
% Final release version 1.4 (2002/02/07)

sshot=int2str(shot);

% GET THE DATA FROM MDS
	
% check availability of data 

shot=mdsopen('tcv_shot',shot);
pts=mdsdata('\results::npts_contour')-1;

% check whether data is available for this shot

if (pts(1) == -1)

  disp(['NO LIUQE DATA AVAILABLE FOR SHOT: ',sshot]);
  return;
  
end

% get valid timebase

tbase=mdsdata('dim_of(\results::r_axis)');
	
% ensure that 'time' is within range

if min(times)<min(tbase)

  c_time1=1.001*min(tbase); s_c_times1=num2str(c_time1);
  disp(['WARNING: min time  out of range, using T =' s_c_times1 '[s] instead']);
  
end

if max(times)>max(tbase)

  c_time2=0.999*max(tbase); s_c_times2=num2str(c_time2);
  disp(['WARNING: max time out of range, using T =' s_c_times2 '[s] instead']);
  
end
	
ii=1;

for k=1:length(times)
	
  indext=max(find(abs(times(k)-tbase)==min(abs(times(k)-tbase))));

  if ii==1
		
    c_times(ii)=tbase(indext);
	ii=ii+1;
    
  else
      
    if tbase(indext)>c_times(ii-1)
		
      c_times(ii)=tbase(indext); 
	  ii=ii+1;
      
    end
    
  end
  
end

con_xt=mdsdata('\results::r_contour[*,$]',c_times);
con_yt=mdsdata('\results::z_contour[*,$]',c_times);

con_xt=con_xt*100;
con_yt=con_yt*100;

c_xt=(mdsdata('\results::r_axis[$]',c_times)*100);
c_yt=mdsdata('\results::z_axis[$]',c_times)*100;
	
mdsclose;

if length(c_times)>1

  con_xt(find(con_xt==0))=NaN*ones(size(find(con_xt==0)));
  con_yt(find(con_xt==0))=NaN*ones(size(find(con_xt==0)));
  
else

  con_xt=con_xt(find(con_xt~=0));
  con_yt=con_yt(find(con_xt~=0));
  
end

return