function bolmov(shot,wperclev)

% bolmov(shot,level) / without argument runs last shot, level=100
%
% Loads results of fast SXR tomography. Uses BLACK AND WHITE contours for
% displaying emission profiles. Shows plasma position, allows MOVIE run.
% By default the emission level is 20 kW.m^(-3) but this can be changed 
% by the second function parameter. 

% Jan Mlynar Sept 2001
% version bolometry ... January 2002

global bm_maincat bm_movieaxis bm_shotnum bm_comment bm_framenum bm_chisq...
       bm_lambda bm_Ptot bm_Pup bm_Pbot bm_play bm_repeat bm_speed ...
       bm_delchans bm_delchans2

global shotnum tsteps comment g_bolo Ptot lambda rpix zpix tvec chisq ...
       rmag zmag moma maxlev clevs wperc Pup Pbot delchans

if nargin<1
   shot=21518;
end   

if isnumeric(shot)
   action='start';
   shotnum=shot;
   if nargin<2
      wperc=20000;  % W.m^(-3) per contour
   else
      wperc=wperclev;   
   end   
else
   action=shot;   
end   

switch action

case 'start'

   bm_maincat=bolmovgui;
   zoom on; 
   
   bm_movieaxis=findobj(bm_maincat,'Tag','movieaxes');
   bm_shotnum=findobj(bm_maincat,'Tag','shotnum');
   bm_comment=findobj(bm_maincat,'Tag','comment');
   bm_framenum=findobj(bm_maincat,'Tag','framenum');
   bm_chisq=findobj(bm_maincat,'Tag','chisq');
   bm_lambda=findobj(bm_maincat,'Tag','lambda');
   bm_Ptot=findobj(bm_maincat,'Tag','Ptot');
   bm_Pup=findobj(bm_maincat,'Tag','Pup');
   bm_Pbot=findobj(bm_maincat,'Tag','Pbot');
   bm_play=findobj(bm_maincat,'Tag','play');
   bm_repeat=findobj(bm_maincat,'Tag','repeat');
   bm_speed=findobj(bm_maincat,'Tag','speed');
   bm_delchans=findobj(bm_maincat,'Tag','delchans');
   bm_delchans2=findobj(bm_maincat,'Tag','delchans2');
   

   axes(bm_movieaxis);
   axis equal; 
   axis([.6 1.2 -.8 .8]);  
 
  
   set(bm_shotnum,'String',int2str(shotnum));

   bolmov('shotnum');
   return
   
case 'shotnum'   

   set(bm_comment,'String','...wait please, getting inversions...');
   cla
   drawnow
   
   shotnum=eval(get(bm_shotnum,'String'));

   mdsopen(shotnum);
      
   try
      g_bolo=mdsdata('\results::btomo:emissivity');
     
 
      comment=mdsdata('\results::btomo:comment');
      delchans=mdsdata('\results::btomo:nchord');
      Ptot=mdsdata('\results::btomo:prad_tot');
      lambda=mdsdata('\results::btomo:lambda');
      rpix=mdsdata('\results::btomo:rmesh');
      zpix=mdsdata('\results::btomo:zmesh');
      tvec=mdsdata('\results::btomo:time');
      chisq=mdsdata('\results::btomo:chi_squared');   
      Pup=mdsdata('\results::btomo:prad_above');
      Pbot=mdsdata('\results::btomo:prad_below');
   catch
      comment=' Data problem, sorry.'
   end   
   
   mdsclose;
      
   if length(delchans)<20
      delchans1=int2str(delchans');;
      delchans2=[];
   else
      delchans1=int2str(delchans(1:19)');
      delchans2= int2str(delchans(20:length(delchans))');
   end   
   
   nr=length(rpix);nz=length(zpix);
   tsteps=length(tvec);
   g_bolo=reshape(g_bolo,nz,nr,tsteps);     
   
   set(bm_comment,'String',comment);
       pause(3)
   set(bm_delchans,'String',delchans1);
   set(bm_delchans2,'String',delchans2);
	  set(bm_lambda,'String',num2str(lambda,4));
   
   if tsteps==0 
      set(bm_comment,'String','No data, sorry.');
      return; 
   end

   if isnan(Pup) Pup=NaN*ones(size(tvec)); end
   if isnan(Pbot) Pbot=NaN*ones(size(tvec)); end
 
   set(bm_comment,'String','  ...wait please, making frames...');
   
   maxlev=max(g_bolo(:));
   clevs=[0:wperc:maxlev];  
     
    bfr=5;                  % number of empty frames     
    
   for ti=1:tsteps
      cla      
 	    [con,hcon]=contour(rpix,zpix,g_bolo(:,:,ti),clevs,'k');
        
	     hold on;
%	     plot([.6 1.15], [lambda(ti)/100 lambda(ti)/100],'b');
%     	plot([Ptot(ti)/100 Ptot(ti)/100], [-.8 .8],'b'); 
%	    plot([.6 1.15], [zmag(ti)/100 zmag(ti)/100],'m');
%	    plot([rmag(ti)/100 rmag(ti)/100], [-.8 .8],'m'); 
	
	     text(.65,-.68,'FRAME');text(.95,-.68,'TIME');
	     text(.78,-.75,int2str(ti));text(1,-.75,num2str(tvec(ti),4));
	     text(.65,.74,[int2str(wperc/1000) ' kW.m^{-3}/cont.']);
	
	     hold off;
      caxis([0 maxlev]);
	     axis equal;shading flat;       
      axis([.6 1.15 -.8 .8]);
	     title(['shot #' int2str(shotnum)]);
	     xlabel('r [cm]');
	     ylabel('z [cm]');
 	
	     set(bm_framenum,'String',num2str(ti));

	     set(bm_Ptot,'String',num2str(Ptot(ti)/1000,4));
	     set(bm_Pup,'String',num2str(Pup(ti)/1000,4));
	     set(bm_Pbot,'String',num2str(Pbot(ti)/1000,4));
	     set(bm_chisq,'String',num2str(chisq(ti),4));

	
	     if ti==1  % moviein is not necessary in MatLab6
         moma=moviein(tsteps+bfr,bm_movieaxis);  
	     end	             

	     moma(:,ti)=getframe(bm_movieaxis);
    end
    cla;
    for blanc=1:bfr	        % to distinguish the end in movie reply
	      moma(:,tsteps+blanc)=getframe(bm_movieaxis);
    end	
    set(bm_framenum,'String','1');
    bolmov('framenum')
    return;
    
case 'play'
     set(bm_comment,'String','Playing movie...');
   
     repeat=eval(get(bm_repeat,'String'));    
     speed=eval(get(bm_speed,'String')); 
     movie(moma,repeat,speed);
     
     bolmov('framenum')
     return

case 'chan>'

     framenum=eval(get(bm_framenum,'String'))+1;
     set(bm_framenum,'String',int2str(framenum))
     bolmov('framenum');
     return
      
case 'chan<'

     framenum=eval(get(bm_framenum,'String'))-1;
     set(bm_framenum,'String',int2str(framenum))
     bolmov('framenum');
     return

case 'framenum'
     set(bm_comment,'String','........');
     ti=eval(get(bm_framenum,'String'));
     if ti<1 ti=1;      
        set(bm_comment,'String','..hey, don''t exaggerate!');pause(1);
     end  
     if ti>tsteps ti=tsteps;        
        set(bm_comment,'String','..hey, don''t exaggerate!');pause(1);
     end 
     drawnow
     cla
    	contour(rpix,zpix,g_bolo(:,:,ti),clevs,'k');
	    hold on;
%	    plot([.6 1.15], [lambda(ti)/100 lambda(ti)/100],'b');
%	    plot([Ptot(ti)/100 Ptot(ti)/100], [-.8 .8],'b'); 
%	    plot([.6 1.15], [zmag(ti)/100 zmag(ti)/100],'m');
%	    plot([rmag(ti)/100 rmag(ti)/100], [-.8 .8],'m'); 
	
    	text(.65,-.68,'FRAME');text(.95,-.68,'TIME');
	    text(.78,-.75,int2str(ti));text(1,-.75,num2str(tvec(ti),4));
	    text(.65,.74,[int2str(wperc/1000) ' kW.m^{-3}/cont.']);
	
    	hold off;
     caxis([0 maxlev]);
	    axis equal;shading flat;       
     axis([.6 1.15 -.8 .8]);
	    title(['shot #' int2str(shotnum)]);
	    xlabel('r [cm]');
	    ylabel('z [cm]');
 	
    	set(bm_framenum,'String',num2str(ti));

    	set(bm_Ptot,'String',num2str(Ptot(ti)/1000,4));
	    set(bm_lambda,'String',num2str(lambda,4));
	    set(bm_Pup,'String',num2str(Pup(ti)/1000,4));
	    set(bm_Pbot,'String',num2str(Pbot(ti)/1000,4));
	    set(bm_chisq,'String',num2str(chisq(ti),4));
       
     set(bm_comment,'String','Ready.');
	 
     return
end  

