function fabsetetendue

% function fabsetetendue
%
% Calculates detector etendue for bolometer tomography.
%
% History:        
%
%  Christian Schlatter, TPIV CRPP EPFL, February 2002 (first release)
%  
% Final release version 1.4 (2002/02/07)

disp(' ');
disp('Etendue calculator for bolometry.');
disp('Final release 1.4');
disp('Latest modification on 2002/02/07.');
disp(' '); 

cw=1;                           % detector numbers cw = 1 : clockwise
                                % cw = 0 : counterclockwise
fans=[1 1 1 1 1 1 1 1];         % camera switch
vangle=[90 0 0 0 0 0 0 -90];    % angle of detector surface normal 

xpos=[88 123.5 123.5 123.5 123.5 123.5 123.5 88]; 

                                % x position of the diaphragmas in [cm]

ypos=[81.5 45.5 45.5 -.25 -.25 -46 -46 -81.5];

                                % y position of the diaphragmas in [cm]
  
% Positions of the detectors

rdet=[0.862,0.867,0.8721,0.8771,0.8829,0.8879,0.893,0.898,...
1.278,1.2806,1.2833,1.2861,1.2883,1.2893,1.2902,1.2912];

rdet(17:24)=fliplr(rdet(9:16));
rdet(25:40)=rdet(9:24);
rdet(41:56)=rdet(9:24);
rdet(57:64)=fliplr(rdet(1:8));

zdet=[0.9057,0.9063,0.9069,0.9075];
zdet(5:8)=fliplr(zdet(1:4));
zdet(9:24)=[0.4916,0.4873,0.483,0.4787,0.473,0.468,0.4631,0.4581,...
0.4519,0.4469,0.442,0.437,0.4313,0.427,0.4227,0.4184];
zdet(25:40)=zdet(9:24)-0.4575;
zdet(41:56)=zdet(9:24)-0.915;
zdet(57:64)=-zdet(1:8);

xdet=rdet*100; ydet=zdet*100;

d1=1.5/10;			        % detector width in cm
d2=4/10;			        % detector length in cm
b1=[2.6 2.2 2.2 2.2 2.2 2.2 2.2 2.6]/5;			 

                            % aperture width in cm (poloidal)
b2=[10 8 8 8 8 8 8 10]/5;	% aperture length in cm (toroidal)
 
% Calculation of aperture and detector positions

nact=sum(fans);
iact=find(fans);
ndet=8;
ncam=8;

xap=ones(ndet,1)*xpos;
xap=xap(:)';
yap=ones(ndet,1)*ypos;
yap=yap(:)';
be1=ones(ndet,1)*b1;
be1=be1(:)';
be2=ones(ndet,1)*b2;
be2=be2(:)';

x0=xdet-xap;
y0=ydet-yap;

ivert=[1:8,57:64]';
x0(ivert)=ydet(ivert)-yap(ivert);
y0(ivert)=xdet(ivert)-xap(ivert);

alpha=atan(y0./x0);
 
rsquare=x0.^2+y0.^2;

etend=d1*d2*be1.*be2.*cos(alpha).^2./rsquare;

                          % The bolometers etendue
  
save fabetendue.mat etend; % Save to disk

disp('File fabetendue.mat successfully created.');
disp(' ');