function fabsett

% function fabsett
%
% Calculation of the T matrix for a rectangular grid using precalculated
% matrices of solid angles for all detectors and a grid of 0.5x0.5x0.5cm^3
% The solid angle matrices has to be called 'fabangle_#.mat' and need to be
% stored in a subdirectory called \fabsolidangle\.
%
% This uses the 3 dimensional omgrid algorithm (fabangle.m)
% This is the version for bolometry.
%
% The variables nx ny xmin xmax ymin ymax dx dy xmesh ymesh numdet T
% are stored to the file fabt.mat for use with fabcat.m.
%
% History:
%
%  Christian Schlatter, TPIV CRPP EPFL, November 2001
%  
% Final release version 1.4 (2002/02/07)

disp(' ') 
disp('FABCAT T-matrix calculator for bolometry.');
disp('Final release 1.4')
disp('Latest modification on 2002/02/07.') 
disp(' '); 

% Tokamak setup parameters for placing the rectangular grid.
% Values correspond to the default values in the btomo package.
% All values given in [cm]

r_0 = 88;     % radial position of the rectangular grid center
z_0 = 0;      % z-coordinate of the rectangular grid center
w_r = 55;     % horizontal width of the grid
w_z = 154;    % vertical width of the grid
nx = 10;      % hoizontal number of pixels

% Camera setup (bolometry detectors)

f_cam = [1 1 1 1 1 1 1 1];

xmin=r_0-w_r/2;
xmax=r_0+w_r/2;
ymin=z_0-w_z/2;
ymax=z_0+w_z/2;

dx=(xmax-xmin)/nx;
dy=dx;

ny = ceil((ymax-ymin)/dy);
ymin = z_0-ny/2*dy;
ymax = z_0+ny/2*dy;

xmesh = xmin+dx/2:dx:xmax-dx/2;
ymesh = ymin+dy/2:dy:ymax-dy/2;

[T,numdet] = fabangle(f_cam, xmin, xmax, ymin, ymax, nx, ny);

save fabt.mat nx ny xmin xmax ymin ymax dx dy xmesh ymesh numdet T;

disp('File fabt.mat successfully created.')
disp(' ');