function [xl1, yl1, xl2, yl2] = ...
    fabproject(xb1, yb1, xb2, yb2, xd1, yd1, xd2, yd2, xi, yi)

% function [xl1, yl1, xl2, yl2] = ...
%     fabproject(xb1, yb1, xb2, yb2, xd1, yd1, xd2, yd2, xi, yi)
%
% Calculates the projection of two points xb1,xb2,yb1,yb2 on a line
% defined by xd1,yd1,xd2,yd2. The point of projection is xi,yi.
%
% sizes: xb1,yb1,xb2,yb2,xd1,yd1,xd2,yd2	1x1
% 		 xi,yi	                            arbitrary
% 		 xl1,yl1,xl2,yl2	                same size as xi,yi 
%
% This program is a subroutine of 'fab3d.m'
%
% History:        
%
%  Matthias Anton, CRPP EPFL, 29 of May, 1995 (first release)
%  Christian Schlatter, TPIV CRPP EPFL, February 2002 (comments and renaming)
%  
% Final release version 1.4 (2002/02/07)

xl1=zeros(size(xi));
xl2=zeros(size(xi));
yl1=zeros(size(xi));
yl2=zeros(size(xi));

p1=( yi*(xb1-xd1)-xi*(yb1-yd1)+xd1*yb1-yd1*xb1 ) ./ ....
   ( (yb1-yi)*(xd1-xd2)-(xb1-xi)*(yd1-yd2) );

p2=( yi*(xb2-xd1)-xi*(yb2-yd1)+xd1*yb2-yd1*xb2 ) ./ ....
   ( (yb2-yi)*(xd1-xd2)-(xb2-xi)*(yd1-yd2) );

xb1d=xd1+p1*(xd2-xd1);
yb1d=yd1+p1*(yd2-yd1);
xb2d=xd1+p2*(xd2-xd1);
yb2d=yd1+p2*(yd2-yd1);

iia = find( (p1<0 & p2<0) | (p1>1 & p2>1) );
iib = find( p1<=1 & p1>=0 & p2>=0 & p2<=1 );
iic = find( (p1<0 & p2>1) | (p2<0 & p1>1) );
iid = find( p1>=0 & p1<=1 &  p2>1 );
iie = find( p1>=0 & p1<=1 &  p2<0 );
iif = find( p2>=0 & p2<=1 &  p1>1 );
iig = find( p2>=0 & p2<=1 &  p1<0 );

if ~isempty(iia);
  
  xl1(iia)=xi(iia);
  xl2(iia)=xi(iia);
  yl1(iia)=yi(iia);
  yl2(iia)=yi(iia);
  
end

if ~isempty(iia);

  xl1(iia)=99999*ones(size(iia));
  xl2(iia)=99999*ones(size(iia));
  yl1(iia)=99999*ones(size(iia));
  yl2(iia)=99999*ones(size(iia));

end

if ~isempty(iib);

  xl1(iib)=xb1d(iib);
  xl2(iib)=xb2d(iib);
  yl1(iib)=yb1d(iib);
  yl2(iib)=yb2d(iib);

end

if ~isempty(iic);

  xl1(iic)=xd1*ones(size(iic));
  xl2(iic)=xd2*ones(size(iic));
  yl1(iic)=yd1*ones(size(iic));
  yl2(iic)=yd2*ones(size(iic));

end

if ~isempty(iid);

  xl1(iid)=xd2*ones(size(iid));
  xl2(iid)=xb1d(iid);
  yl1(iid)=yd2*ones(size(iid));
  yl2(iid)=yb1d(iid);

end

if ~isempty(iie);

  xl1(iie)=xd1*ones(size(iie));
  xl2(iie)=xb1d(iie);
  yl1(iie)=yd1*ones(size(iie));
  yl2(iie)=yb1d(iie);

end

if ~isempty(iif);

  xl1(iif)=xd2*ones(size(iif));
  xl2(iif)=xb2d(iif);
  yl1(iif)=yd2*ones(size(iif));
  yl2(iif)=yb2d(iif);

end

if ~isempty(iig);

  xl1(iig)=xd1*ones(size(iig));
  xl2(iig)=xb2d(iig);
  yl1(iig)=yd1*ones(size(iig));
  yl2(iig)=yb2d(iig);

end

