function fabstore(shot, rm, zm, time, X, lambda, Sigma, ...
            logchi2, smoothing,	nchords, mtxt, ctxt, Ptot, ...
            Pin, Pout, Pabove, Pbelow);

% function fabstore(shot, rm, zm, time, X, lambda, Sigma, ...
%            logchi2, smoothing,	nchords, mtxt, ctxt, Ptot, ...
%            Pin, Pout, Pabove, Pbelow);
%
% Stores the results of the reconstruction in the MDS tree.
% ATTENTION: whatever may be there will be overwritten.			
%
% This routine has been taken from the boloti package.
%
% Arguments:
%
% 	 shot		the shotnumber      			[1 x 1]		
%	 rm		    pixel coordinates 		        [1 x nr]	
%	 zm   		idem 				            [1 x nz]	
%	 time		times for the slices inverted 	[1 x timesteps]	
%	 X		    normalised emissivity (max=1)	[npixels x timesteps]
%	 lambda		smoothing factor of reconstr. 	[1 x timesteps] 
% 	 Sigma		data error in %			        [1 x 1]		
%	 logchi2	log10(chi2/length(nchords))	    [3 x timesteps]	
%	 smoothing 	number of points averaged in 	[1 x 1]		
%	 		    bolo-data treatment				
%	 nchords	number of bolo-chords used	    [1 x 1]		
%	 mtxt		comment on inversion method		string
% 	 Ptot		total radiated power [Pin+Pout] [1 x timesteps]	
%	 Pin		radiated power inside LCFS 	    [1 x timesteps]	
%	 Pout  		radiated power outside LCFS 	[1 x timesteps]	
%	 Pabove		radiated power above LCFS 	    [1 x timesteps]	
%	 Pbelow		radiated power below LCFS	    [1 x timesteps]	
%
% All radiation given in [W]					
%
% History:        
%
%  Arno Refke, CRPP EPFL, 20 of November, 1998 (first release)
%  
% Final release version 1.4 (2002/02/07)

if nargin~=17

    error('fabstore.m: sorry, incorrect number of input arguments')
	return
    
end

cmd1 = 'build_signal(build_with_units(f_float($1),"W"),*,f_float($2))';

mdsopen('results',shot)

mdsput('\results::btomo:method',mtxt,'t');
mdsput('\results::btomo:comment',ctxt,'t');

mdsput('\results::btomo:rmesh',rm,'f');
mdsput('\results::btomo:zmesh',zm,'f');
mdsput('\results::btomo:nchord',nchords,'f');
mdsput('\results::btomo:lambda',lambda,'f');
mdsput('\results::btomo:sigma',Sigma,'f');
mdsput('\results::btomo:chi_squared',logchi2,'f');
mdsput('\results::btomo:smoothing',smoothing,'f');
mdsput('\results::btomo:time',time,'f');
mdsput('\results::btomo:emissivity',.....
	'Build_signal($1,*,*,\results::btomo:time)','x',X);

mdsput('\results::btomo:prad_above',cmd1,'x',Pabove,time);
mdsput('\results::btomo:prad_below',cmd1,'x',Pbelow,time);
mdsput('\results::btomo:prad_in',cmd1,'x',Pin,time);
mdsput('\results::btomo:prad_out',cmd1,'x',Pout,time);
mdsput('\results::btomo:prad_tot',cmd1,'x',Ptot,time);
	
mdsclose;

return